@@ -1,5 +1,5 @@
 package USPS::RateRequest;
-$USPS::RateRequest::VERSION = '1.0000';
+$USPS::RateRequest::VERSION = '1.0001';
 use strict;
 use Moose;
 use XML::DOM;
@@ -16,7 +16,7 @@ USPS::RateRequest - Ultra fast parallelized asyncronous USPS rate lookups.
 
 =head1 VERSION
 
-version 1.0000
+version 1.0001
 
 =head1 SYNOPSIS
 
@@ -414,6 +414,11 @@ sub _handle_responses {
 
 sub _handle_response {
     my ($self, $response, $rates) = @_;
+
+    unless (ref $response eq 'HTTP::Response') {
+        ouch 500, $response;
+    }
+
     if ($self->debug) {
         say $response->decoded_content;
     }
@@ -501,6 +506,8 @@ sub sanitize_service_name {
     $name =~ s/GXG/Global Express Guaranteed/gi;
     $name =~ s/ Mail//gi;
     $name =~ s/ \d-Day//gi;
+    $name =~ s/ APO\/FPO\/DPO//gi;
+    $name =~ s/ Military//gi;
     $name =~ s/ International//gi;
     $name =~ s/USPS //gi;
     $name =~ s/Envelopes/Envelope/gi;
